package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.ContrastRecord;
import com.ruoyi.mall.domain.Vo.ContrastRecordVo;

/**
 * 添加对比记录Service接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface IContrastRecordService 
{
    /**
     * 查询添加对比记录
     * 
     * @param recordId 添加对比记录主键
     * @return 添加对比记录
     */
    public ContrastRecord selectContrastRecordByRecordId(Long recordId);

    /**
     * 查询添加对比记录列表
     * 
     * @param contrastRecord 添加对比记录
     * @return 添加对比记录集合
     */
    public List<ContrastRecord> selectContrastRecordList(ContrastRecord contrastRecord);
    /**
     * 查询已添加对比记录列表 vo 大学对比 已添加学校列表展示
     * @param contrastRecordVo 添加对比记录
     * @return 添加对比记录集合（含学校详细信息）
     */
    List<ContrastRecordVo> selectContrastRecordVoList(ContrastRecordVo contrastRecordVo);
    /**
     * 新增添加对比记录
     * 
     * @param contrastRecord 添加对比记录
     * @return 结果
     */
    public int insertContrastRecord(ContrastRecord contrastRecord);

    /**
     * 修改添加对比记录
     * 
     * @param contrastRecord 添加对比记录
     * @return 结果
     */
    public int updateContrastRecord(ContrastRecord contrastRecord);

    /**
     * 批量删除添加对比记录
     * 
     * @param recordIds 需要删除的添加对比记录主键集合
     * @return 结果
     */
    public int deleteContrastRecordByRecordIds(Long[] recordIds);

    /**
     * 删除添加对比记录信息
     * 
     * @param recordId 添加对比记录主键
     * @return 结果
     */
    public int deleteContrastRecordByRecordId(Long recordId);
}
