package com.ruoyi.mall.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.ContrastRecord;
import com.ruoyi.mall.service.IContrastRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 添加对比记录Controller
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
@RestController
@RequestMapping("/mall/contrastRecord")
public class ContrastRecordController extends BaseController
{
    @Autowired
    private IContrastRecordService contrastRecordService;

    /**
     * 查询添加对比记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(ContrastRecord contrastRecord)
    {
        startPage();
        List<ContrastRecord> list = contrastRecordService.selectContrastRecordList(contrastRecord);
        return getDataTable(list);
    }

    /**
     * 导出添加对比记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:export')")
    @Log(title = "添加对比记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ContrastRecord contrastRecord)
    {
        List<ContrastRecord> list = contrastRecordService.selectContrastRecordList(contrastRecord);
        ExcelUtil<ContrastRecord> util = new ExcelUtil<ContrastRecord>(ContrastRecord.class);
        util.exportExcel(response, list, "添加对比记录数据");
    }

    /**
     * 获取添加对比记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return AjaxResult.success(contrastRecordService.selectContrastRecordByRecordId(recordId));
    }

    /**
     * 新增添加对比记录
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:add')")
    @Log(title = "添加对比记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ContrastRecord contrastRecord)
    {
        return toAjax(contrastRecordService.insertContrastRecord(contrastRecord));
    }

    /**
     * 修改添加对比记录
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:edit')")
    @Log(title = "添加对比记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ContrastRecord contrastRecord)
    {
        return toAjax(contrastRecordService.updateContrastRecord(contrastRecord));
    }

    /**
     * 删除添加对比记录
     */
    @PreAuthorize("@ss.hasPermi('mall:contrastRecord:remove')")
    @Log(title = "添加对比记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(contrastRecordService.deleteContrastRecordByRecordIds(recordIds));
    }
}
